"""`damask_parse.__init__.py`"""

from pathlib import Path

import pandas

from damask_parse.utils import resolve_dataframe_arrays


def get_num_header_lines(path):
    """Get the number of header lines from a file produced by DAMASK.

    Parameters
    ----------
    path : str or Path
        Path to a DAMASK-generated file that contains a header.

    Returns
    -------
    num : int
        Number of header lines in the DAMASK-generated file.

    """

    path = Path(path)
    with path.open() as handle:
        num = int(handle.read(1))

    return num


def parse_damask_table(path):
    """Read the data from a DAMASK-generated ASCII table file, as generated by
    the DAMASK post-processing command named `postResults`.

    Parameters
    ----------
    path : str or Path
        Path to the DAMASK table file.

    Returns
    -------
    outputs : dict
        Dictionary of Numpy arrays corresponding to the data in the table file.

    """

    header_num = get_num_header_lines(path)
    df = pandas.read_csv(str(path), delim_whitespace=True, header=header_num)
    outputs = resolve_dataframe_arrays(df)

    return outputs
